
.. automodule:: bci_framework.extensions
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bci_framework.extensions.data_analysis
   bci_framework.extensions.stimuli_delivery
   bci_framework.extensions.visualizations

Submodules
----------

.. toctree::
   :maxdepth: 4

   bci_framework.extensions.properties
